import React, { useEffect, useRef, useState } from "react";
import { Row, Col } from "react-bootstrap";
import { Link } from "react-router-dom";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { CarouselProvider, Slider, Slide, ButtonBack, ButtonNext } from "pure-react-carousel";
import categoryDataAccess from "dataAccess/categoryDataAccess";

export default function NavbarAllProductDropdown({ hideMenu }: { hideMenu: Function }) {
   const menuRef = useRef(null);
   useEffect(() => {
      const handleClickOutside = (event: Event) => {
         if (menuRef.current && !menuRef.current.contains(event.target)) {
            hideMenu();
         }
      };
      document.addEventListener("mousedown", handleClickOutside);
      return () => {
         document.removeEventListener("mousedown", handleClickOutside);
      };
   }, [hideMenu]);

   const [mainCategory, setMainCategory] = useState([]);
   useEffect(() => {
      categoryDataAccess
         .getCategoryTreeView()
         .then((data) => {
            setMainCategory(data);
         })
         .catch((error) => {});
   }, []);

   const totalCategory = mainCategory.length;
   const [totalSubCategory, setTotalSubCategory] = useState([]);
   const [windowWidth, setWindowWidth] = useState(window.innerWidth);

   const [categoryColumnOne, setCategoryColumnOne] = useState(false);
   const [categoryColumnTwo, setCategoryColumnTwo] = useState(false);
   const [categoryColumnThree, setCategoryColumnThree] = useState(false);
   const [categoryColumnFour, setCategoryColumnFour] = useState(false);
   if (totalCategory >= 1 && totalCategory <= 7) {
      setCategoryColumnOne(true);
      if (totalCategory >= 8 && totalCategory <= 14) {
         setCategoryColumnTwo(true);
         if (totalCategory >= 15 && totalCategory <= 21) {
            setCategoryColumnThree(true);
            if (totalCategory >= 22 && totalCategory <= 28) {
               setCategoryColumnFour(true);
            }
         }
      }
   }

   const getVisibleSlides = () => {
      if (windowWidth > 992) {
         return 5;
      } else if (windowWidth > 768) {
         return 4;
      } else if (windowWidth > 576) {
         return 2;
      } else {
         return 1;
      }
   };

   return (
      <div ref={menuRef} className="all-products-dropdown">
         <CarouselProvider
            naturalSlideWidth={500}
            naturalSlideHeight={140}
            totalSlides={totalCategory}
            visibleSlides={getVisibleSlides()}
            isIntrinsicHeight={true}
            className="products-slider"
         >
            <Slider style={{ margin: "0px -15px" }} className="sliders">
               {mainCategory.map((category, index) => (
                  <Slide index={index} className="slider-item">
                     <div className="parent-category">
                        <div className="dropdown-header">
                           <FontAwesomeIcon icon={category.icon ? category.icon : "beer"} color="white" />
                        </div>
                        <div className="title">
                           <span> {category.name} </span>
                        </div>
                     </div>
                     <hr />
                     <div className="sub-category" style={{ maxHeight: "20px" }}>
                        {category.child &&
                           category.child.length > 0 &&
                           category.child.map((child, index) => {
                              return (
                                 <div className="item" key={index} style={{ float: "left" }}>
                                    <p>
                                       {" "}
                                       <Link to=""> {child.name} </Link>{" "}
                                    </p>
                                 </div>
                              );
                           })}
                     </div>
                  </Slide>
               ))}
            </Slider>
            <div className="prev-next">
               {" "}
               {/* next and previous btn */}
               <ButtonBack style={{ background: "transparent", border: "0px" }}>
                  <img src="/images/arrowleft.png" alt="Previous product" />
               </ButtonBack>
               <ButtonNext style={{ background: "transparent", border: "0px" }}>
                  <img src="/images/arrowright.png" alt="Next product" />
               </ButtonNext>
            </div>
         </CarouselProvider>

         <div className="our-offer-btn">
            <div className="our-offer-in-header-menu">
               <div>
                  <img src="/images/giftyellow.png" alt="shopstick" />
               </div>
               <div className="offer-text">
                  <span> Our Offers </span>
               </div>
            </div>
         </div>
      </div>
   );
}
